
# Slot: doc




URI: [nwb_schema_language:schema__doc](https://w3id.org/p2p_ld/nwb-schema-language/schema__doc)


## Domain and Range

None &#8594;  <sub>0..1</sub> [String](types/String.md)

## Parents


## Children


## Used by

 * [Schema](Schema.md)
